[−][src]Struct async_ringbuffer::Writer
Write access to a nonblocking ring buffer with fixed capacity.
If there is no space in the buffer to write to, the current task is parked and notified once space becomes available.